@@ -11,7 +11,7 @@ except (ModuleNotFoundError, ValueError):
     from .separate.aggregation import aggregate
     
     
-__version__ = '1.0.6'
+__version__ = '1.0.8'
 from .load_datasets import load_images
 from .symbolic_representation import (image_compress, image_decompress, ABBAbase, ABBA,
                                       get_patches, patched_reconstruction, fABBA,
@@ -20,3 +20,8 @@ from .symbolic_representation import (image_compress, image_decompress, ABBAbase
 from .symbolic_representation import _compress as compress
 from .symbolic_representation import _inverse_compress as inverse_compress
 from .digitization import digitize, inverse_digitize, quantize, wcss, calculate_group_centers
+
+from .jabba.jabba import fastABBA, JABBA
+from .jabba import jabba
+from .jabba.fkmns import sampledKMeansInter as fkmeans
+from .jabba.loadData import *
\ No newline at end of file
